;;; bugtrack-init.el --- Initialize the bugtrack system.

;; Copyright (C) 1992, 1993, 1994 Per Cederqvist.

;; Author: Per Cederqvist <ceder@lysator.liu.se>
;; Created: 1993-12-10
;; Version: Id: bugtrack-init.el,v 1.8 1994/01/06 22:23:40 ceder Exp 
;; Keywords: tools, bugtracking, rolodex, bug, track

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License
;; as published by the Free Software Foundation; either version 2
;; of the License, or (at your option) any later version.
     
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
     
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:

;; Loading this file ensures that bugtrack is ready to use.  It
;; creates key bindings for the bugtrack commands that is available
;; from the RMAIL mode, and adds autoloads for all functions that
;; should be autoloaded.  Apart from that, this file does as little as
;; possible, so that it shouldn't cost too much to always load it.

;; See bugtrack.el and the doc strings.  Note that most, but not all,
;; of this file is auto-generated.


;;; Code:

(defun bugtrack-rmail-init ()
  "Initialize the Bugtrack RMAIL bindings."
  (define-key rmail-mode-map "^" 'bugtrack-rmail-view-commented)
  (define-key rmail-mode-map "M" 'bugtrack-rmail-memorize-msg-id)
  (define-key rmail-mode-map "C" 'bugtrack-rmail-create-bug)
  (define-key rmail-mode-map "F" 'bugtrack-rmail-search-msg-id))

(if (featurep 'rmail)
    (bugtrack-rmail-init))
(eval-after-load "rmail" '(bugtrack-rmail-init))

;;;; The rest of this file is auto-generated by M-x update-directory-autoloads.

;;;### (autoloads (bugtrack-submit-bug-report bugtrack-version bugtrack-other-frame bugtrack-other-window bugtrack bugtrack-mode) "bugtrack" "bugtrack.el" (11564 35783))
;;; Generated autoloads from bugtrack.el

(autoload (quote bugtrack-mode) "bugtrack" "\
Specialized major mode for editing Bugtrack files.

Movement commands:
------------------
\\<bugtrack-browse-mode-map>
One page forward:   \\[scroll-up]            One page backward:      \\[scroll-down]
One line forward:   \\[next-line]            One line backwark:      \\[previous-line]
Next unclosed bug:  \\[bugtrack-next-unclosed-bug]              Previous unclosed bug:  \\[bugtrack-previous-unclosed-bug]
Next bug:           \\[bugtrack-next-bug]            Previous bug:           \\[bugtrack-previous-bug]
Last bug:           \\[bugtrack-goto-last-bug]              First bug:              \\[bugtrack-goto-first-bug]
Go to a bug Id:     \\[bugtrack-show-bug]  (Give Id as prefix or suffix).

All of the above commands can take a prefix argument.  Just type in
the digits before pressing the key mentioned above.

Search for regexp:    \\[bugtrack-search]   (Give prefix argument to search closed bugs as well.)
Continue last search: \\[bugtrack-search-continue]

Write a ChangeLog heading: \\[bugtrack-add-change-log-head]

Creating and modifying bug reports
----------------------------------
Create a new bug report: \\[bugtrack-create-bug]
Close a bug:             \\[bugtrack-close-bug]
Full text edit:          \\[bugtrack-edit]  (\\<bugtrack-edit-mode-map>Abort your changes with \\[bugtrack-edit-abort],
                             or install them with \\[bugtrack-edit-done].)


Saving the buffer\\<bugtrack-browse-mode-map>
-----------------
Save it:           \\[save-buffer]
Save and burry it: \\[bugtrack-quit]


RMAIL interface\\<rmail-mode-map>
---------------
In RMAIL mode, press  \\[bugtrack-rmail-create-bug]  to create a bug report. The current
\"Message-ID:\" will be inserted in the \"Associated mail:\" field,
and the \"Reported by:\" will be filled in from the \"From:\" field.
In RMAIL mode, press \\[bugtrack-rmail-search-msg-id] to find any bug reports 
that has that mail in its \"Associated mail:\" field.

You can press  \\[bugtrack-rmail-memorize-msg-id]  to remember a \"Message-ID:\", and then insert
the memorized message id in the \"Associated mails:\" field with  \\<bugtrack-browse-mode-map>\\[bugtrack-insert-memorized-id].

\\[bugtrack-display-mail]  circles through the mails in the bug report.  You will be asked
for the name of an RMAIL file to search for the mail if Emacs
can not find it in any of its buffers.


Summaries
---------
Summary by Id:         s i  (or  \\[bugtrack-summary-by-id])
Summary by difficulty: \\[bugtrack-summary-by-difficulty]
Summary by priority:   \\[bugtrack-summary-by-priority]
Summary by severity:   \\[bugtrack-summary-by-severity]

You will get a new buffer, in which you can type: \\<bugtrack-summary-mode-map>

\\[bugtrack-summary-goto-previous]   to display the previous bug.
\\[bugtrack-summary-goto-bug]   to display the current bug.
\\[bugtrack-summary-goto-next]   to display the next bug.
\\[cookie-next-cookie]  or  \\[cookie-previous-cookie]  to move forward or backward in the summary
               buffer without displaying the bug.

Useful variables:
	bugtrack-default-dir   Where you store your Bugtrack files.

You can use \\[bugtrack-submit-bug-report] to send a bug report (or
any other kind of feedback) on Bugtrack." t nil)

(autoload (quote bugtrack) "bugtrack" "\
Visit a bugtrack FILE. The FILE is created if it doesn't exist.
Optional second argument WHERE can be 'window to display the bug in
another window, or 'frame to display it in another frame" t nil)

(autoload (quote bugtrack-other-window) "bugtrack" "\
Run Bugtrack on a FILE in another window." t nil)

(autoload (quote bugtrack-other-frame) "bugtrack" "\
Run Bugtrack on a FILE in another frame." t nil)

(autoload (quote bugtrack-version) "bugtrack" "\
Display the version number (1.3) of bugtrack.
The version number is displayed in the minibuffer.  This function
also returns the version number, as a string." t nil)

(autoload (quote bugtrack-submit-bug-report) "bugtrack" "\
Submit via mail a bug report on bugtrack." t nil)

;;;***

;;;### (autoloads (bugtrack-edit) "bugtrack-edit" "bugtrack-edit.el" (11564 35745))
;;; Generated autoloads from bugtrack-edit.el

(autoload (quote bugtrack-edit) "bugtrack-edit" "\
In Bugtrack mode, start to edit the free text." t nil)

;;;***

;;;### (autoloads (bugtrack-display-mail bugtrack-insert-memorized-id bugtrack-rmail-view-commented bugtrack-rmail-search-msg-id bugtrack-rmail-create-bug bugtrack-rmail-memorize-msg-id) "bugtrack-rmail" "bugtrack-rmail.el" (11564 34217))
;;; Generated autoloads from bugtrack-rmail.el

(autoload (quote bugtrack-rmail-memorize-msg-id) "bugtrack-rmail" "\
In RMAIL mode, memorize the msg id for Bugtrack mode." t nil)

(autoload (quote bugtrack-rmail-create-bug) "bugtrack-rmail" "\
In RMAIL mode, create a Bugtrack bug report from the current mail.
Args: BUGTRACK-FILE SUMMARY VERSION MAIL-COMMENT SEVERITY PRIORITY DIFFICULTY.

BUGTRACK-FILE should be an existing Bugtrack file.
SUMMARY is a string that must not contain any colons.
VERSION is a string with the version number of buggy product.
MAIL-COMMENT is a string that is associated with this mail.
SEVERITY, PRIORITY and DIFFICULTY are decimal numbers in the range
0-9, the others are strings that should not contain any newline." t nil)

(autoload (quote bugtrack-rmail-search-msg-id) "bugtrack-rmail" "\
In RMAIL mode, search for any bugs about the current mail.
This will search closed as well as active bugs.  If there are
any Bugtrack cookies in the subject, use them before using the
message Id." t nil)

(autoload (quote bugtrack-rmail-view-commented) "bugtrack-rmail" "\
In RMAIL mode, view the commented mail (if it can be found).
Ask for an RMAIL file to search in, if it can not be found in any
visited RMAIL file. Signal an error if it is not found there either." t nil)

(autoload (quote bugtrack-insert-memorized-id) "bugtrack-rmail" "\
In Bugtrack mode, insert the memorized RMAIL message id in the current bug.
The message ID should be memorized with bugtrack-rmail-memorize-msg-id." t nil)

(autoload (quote bugtrack-display-mail) "bugtrack-rmail" "\
In Bugtrack mode, display associated mail." t nil)

;;;***

;;;### (autoloads (bugtrack-summary-by-difficulty bugtrack-summary-by-severity bugtrack-summary-by-priority bugtrack-summary-by-id) "bugtrack-sum" "bugtrack-sum.el" (11564 35751))
;;; Generated autoloads from bugtrack-sum.el

(autoload (quote bugtrack-summary-by-id) "bugtrack-sum" "\
In Bugtrack mode, create a summary.
If optional prefix argument INCLUDE-CLOSED is non-nil, closed
bug reports are also included in the summary." t nil)

(autoload (quote bugtrack-summary-by-priority) "bugtrack-sum" "\
In Bugtrack mode, create a summary sorted by priority.
If optional prefix argument INCLUDE-CLOSED is non-nil, closed
bug reports are also included in the summary." t nil)

(autoload (quote bugtrack-summary-by-severity) "bugtrack-sum" "\
In Bugtrack mode, create a summary sorted by severity.
If optional prefix argument INCLUDE-CLOSED is non-nil, closed
bug reports are also included in the summary." t nil)

(autoload (quote bugtrack-summary-by-difficulty) "bugtrack-sum" "\
In Bugtrack mode, create a summary sorted by difficulty.
If optional prefix argument INCLUDE-CLOSED is non-nil, closed
bug reports are also included in the summary." t nil)

;;;***
;;; bugtrack-init.el ends here
